@@ -10,7 +10,7 @@ package Devel::Cover;
 use strict;
 use warnings;
 
-our $VERSION = '0.89'; # VERSION
+our $VERSION = '0.93'; # VERSION
 our $LVERSION = do { eval '$VERSION' || "0.001" };  # for development purposes
 
 use DynaLoader ();
@@ -105,7 +105,25 @@ BEGIN
               ($ENV{PERL5OPT}              || "") =~ /Devel::Cover/;
     *OUT = $ENV{DEVEL_COVER_DEBUG} ? *STDERR : *STDOUT;
 
-    @Inc = @Devel::Cover::Inc::Inc;
+    eval
+    {
+        local %ENV = %ENV;
+        # Clear *PERL* variables, but keep PERL5?LIB for local::lib environments
+        /perl/i and !/^PERL5?LIB$/ and delete $ENV{$_} for keys %ENV;
+        my $cmd = "$^X -MData::Dumper -e " . '"print Dumper \@INC"';
+        my $VAR1;
+        # print STDERR "Running [$cmd]\n";
+        eval `$cmd`;
+        @Inc = @$VAR1;
+    };
+    if ($@)
+    {
+        print STDERR __PACKAGE__, ": Error getting \@INC: $@\n",
+                                  "Reverting to default value for Inc.\n";
+        @Inc = @Devel::Cover::Inc::Inc;
+    }
+    @Inc = map { -d $_ ? ($_ eq "." ? $_ : Cwd::abs_path($_)) : () } @Inc;
+
     @Ignore = ("/Devel/Cover[./]") unless $Self_cover = $ENV{DEVEL_COVER_SELF};
     # $^P = 0x004 | 0x010 | 0x100 | 0x200;
     # $^P = 0x004 | 0x100 | 0x200;
@@ -274,6 +292,7 @@ sub import
     my $class = shift;
 
     my @o = (@_, split ",", $ENV{DEVEL_COVER_OPTIONS} || "");
+    defined or $_ = "" for @o;
     # print STDERR __PACKAGE__, ": Parsing options from [@o]\n";
 
     my $blib = -d "blib";
@@ -354,7 +373,6 @@ sub import
         $Criteria{$c} = $func->();
     }
 
-    %Coverage = (all => 1) unless keys %Coverage;
     for (keys %Coverage)
     {
         my @c = split /-/, $_;
@@ -363,7 +381,10 @@ sub import
             $Coverage{shift @c} = \@c;
             delete $Coverage{$_};
         }
+        delete $Coverage{$_} unless length;
     }
+    %Coverage = (all => 1) unless keys %Coverage;
+    # print STDERR "Coverage: ", Dumper \%Coverage;
     %Coverage_options = %Coverage;
 
     $Initialised = 1;
@@ -499,7 +520,7 @@ sub get_location
 
     $File = $op->file;
     $Line = $op->line;
-    # warn "${File}::$Line\n";
+    # print STDERR "$File:$Line\n";
 
     # If there's an eval, get the real filename.  Enabled from $^P & 0x100.
     while ($File =~ /^\(eval \d+\)\[(.*):(\d+)\]/) {
@@ -822,6 +843,7 @@ sub add_statement_cover
     my $key = get_key($op);
     my $val = $Coverage->{statement}{$key} || 0;
     my ($n, $new) = $Structure->add_count("statement");
+    # print STDERR "Stmt $File:$Line - $n, $new\n";
     $Structure->add_statement($File, $Line) if $new;
     $Run{count}{$File}{statement}[$n] += $val;
     my $vec = $Run{vec}{$File}{statement};
@@ -829,7 +851,8 @@ sub add_statement_cover
     $vec->{size} = $n + 1;
     no warnings "uninitialized";
     $Run{count}{$File}{time}[$n] += $Coverage->{time}{$key}
-        if exists $Coverage->{time} && exists $Coverage->{time}{$key};
+        if $Coverage{time} &&
+           exists $Coverage->{time} && exists $Coverage->{time}{$key};
 }
 
 sub add_branch_cover
@@ -883,20 +906,11 @@ sub add_branch_cover
     # warn "branch $type %x [@$c] => [@{$ccount->{branch}[$n]}]\n", $$op;
 }
 
-my %condition_locations;
-
 sub add_condition_cover
 {
     my ($op, $strop, $left, $right) = @_;
 
-    unless ($Collect)
-    {
-        # $condition_locations{$$op} = [ $File, $Line ];
-        return
-    }
-
-    # local ($File, $Line) = @{$condition_locations{$$op}}
-        # if exists $condition_locations{$$op};
+    return unless $Collect && $Coverage{condition};
 
     my $key = get_key($op);
     # warn "Condition cover $$op from $File:$Line\n";
@@ -904,13 +918,10 @@ sub add_condition_cover
     # use Carp "cluck"; cluck("from here");
 
     my $type = $op->name;
-    # print STDERR "type:  [$type]\n";
     $type =~ s/assign$//;
     $type = "or" if $type eq "dor";
-    # print STDERR "type:  [$type]\n";
 
     my $c = $Coverage->{condition}{$key};
-    # print STDERR "Condition: ", Dumper $c;
 
     no warnings "uninitialized";
 
@@ -1287,7 +1298,7 @@ Devel::Cover - Code coverage metrics for Perl
 
 =head1 VERSION
 
-version 0.89
+version 0.93
 
 =head1 SYNOPSIS
 
@@ -1495,13 +1506,17 @@ included.
 You may add to the REs to select by using +select, or you may reset the
 selections using -select.  The same principle applies to the REs to ignore.
 
-The inc directories are initially populated with the contents of the @INC
-array at the time Devel::Cover was built.  You may reset these directories
-using -inc, or add to them using +inc.
+The inc directories are initially populated with the contents of perl's @INC
+array.  You may reset these directories using -inc, or add to them using +inc.
 
 Although these options take regular expressions, you should not enclose the RE
 within // or any other quoting characters.
 
+The options -coverage, [+-]select, [+-]ignore and [+-]inc can be specified
+multiple times, but they can also take multiple comma separated arguments.  In
+any case you should not add a space after the comma, unless you want the
+argument to start with that literal space.
+
 =head1 ENVIRONMENT
 
 The -silent option is turned on when Devel::Cover is invoked via
