@@ -1,4 +1,4 @@
-# Copyright 2005-2010, Paul Johnson (pjcj@cpan.org)
+# Copyright 2005-2012, Paul Johnson (paul@pjcj.net)
 
 # This software is free.  It is licensed under the same terms as Perl itself.
 
@@ -10,7 +10,7 @@ package Devel::Cover::Annotation::Svk;
 use strict;
 use warnings;
 
-our $VERSION = "0.73";
+our $VERSION = '0.93'; # VERSION
 
 use Getopt::Long;
 use Digest::MD5;
@@ -51,7 +51,7 @@ sub new
     while (<$c>)
     {
         chomp;
-        s{^\Q$self->{depotbase}\E/}{};
+        s|^\Q$self->{depotbase}\E/||;
         next unless -f $_;
 
         open my $f, $_ or warn "cover: Can't open $_: $!\n", next;
@@ -156,9 +156,13 @@ __END__
 
 Devel::Cover::Annotation::Svk - Annotate with svk information
 
+=head1 VERSION
+
+version 0.93
+
 =head1 SYNOPSIS
 
- cover -report xxx -annotation svk
+ cover -report text -annotation svk  # Or any other report type
 
 =head1 DESCRIPTION
 
@@ -173,13 +177,9 @@ This module is designed to be called from the C<cover> program.
 
 Huh?
 
-=head1 VERSION
-
-Version 0.73 - 2nd October 2010
-
 =head1 LICENCE
 
-Copyright 2005-2010, Paul Johnson (pjcj@cpan.org)
+Copyright 2005-2012, Paul Johnson (paul@pjcj.net)
 
 This software is free.  It is licensed under the same terms as Perl itself.
 
