@@ -1,4 +1,4 @@
-# Copyright 2001-2011, Paul Johnson (pjcj@cpan.org)
+# Copyright 2001-2012, Paul Johnson (paul@pjcj.net)
 
 # This software is free.  It is licensed under the same terms as Perl itself.
 
@@ -10,17 +10,17 @@ package Devel::Cover::DB;
 use strict;
 use warnings;
 
-our $VERSION = "0.77";
+our $VERSION = '0.93'; # VERSION
 
-use Devel::Cover::Criterion     0.77;
-use Devel::Cover::DB::File      0.77;
-use Devel::Cover::DB::Structure 0.77;
-use Devel::Cover::DB::IO        0.77;
+use Devel::Cover::Criterion;
+use Devel::Cover::DB::File;
+use Devel::Cover::DB::Structure;
+use Devel::Cover::DB::IO;
 
 use Carp;
 use File::Path;
 
-use Data::Dumper; $Data::Dumper::Indent = 1; $Data::Dumper::Sortkeys = 1;
+use Devel::Cover::Dumper;  # For debugging
 
 my $DB = "cover.13";  # Version 13 of the database.
 
@@ -28,6 +28,25 @@ my $DB = "cover.13";  # Version 13 of the database.
     (qw( statement branch path condition subroutine pod time ));
 @Devel::Cover::DB::Criteria_short =
     (qw( stmt      bran   path cond      sub        pod time ));
+$Devel::Cover::DB::Ignore_filenames =
+    qr/   # Moose
+        (?:
+            (?:
+                reader | writer | constructor | destructor | accessor |
+                predicate | clearer | native \s delegation \s method |
+                # Template Toolkit
+                Parser\.yp
+            )
+            \s .* \s
+            (?: \( defined \s at \s .* \s line \s \d+ \) | defined \s at )
+        )
+        | # Moose
+        (?: generated \s method \s \( unknown \s origin \) )
+        | # Mouse
+        (?: (?: rw-accessor | ro-accessor ) \s for )
+        | # Template Toolkit
+        (?: Parser\.yp )
+      /x;
 
 sub new
 {
@@ -79,9 +98,9 @@ sub write
     $self->{db} = shift if @_;
 
     croak "No db specified" unless length $self->{db};
-    unless (-d $self->{db})
+    unless (mkdir $self->{db})
     {
-        mkdir $self->{db}, 0700 or croak "Can't mkdir $self->{db}: $!\n";
+        croak "Can't mkdir $self->{db}: $!\n" unless -d $self->{db};
     }
     $self->validate_db;
 
@@ -346,14 +365,21 @@ sub calculate_summary
     return if exists $self->{summary} && !$options{force};
     my $s = $self->{summary} = {};
 
-    for my $file ($self->cover->items)
+    my @files = $self->cover->items;
+    if (my $files = delete $options{files})
+    {
+        my %required_files = map { ($_ => 1) } @$files;
+        @files = grep $required_files{$_}, @files;
+    }
+
+    for my $file (@files)
     {
         $self->cover->get($file)->calculate_summary($self, $file, \%options);
     }
 
     # print STDERR Dumper $self;
 
-    for my $file ($self->cover->items)
+    for my $file (@files)
     {
         $self->cover->get($file)->calculate_percentage($self, $s->{$file});
     }
@@ -378,15 +404,19 @@ sub trimmed_file
 sub print_summary
 {
     my $self = shift;
+    my ($files, $criteria, $opts) = @_;
 
-    my %options = map(($_ => 1), @_ ? @_ : $self->collected);
+    my %crit = map(($_ => 1), $self->collected);
+    my %options = $criteria ? map(($_ => 1), grep $crit{$_}, @$criteria)
+                            : %crit;
     $options{total} = 1 if keys %options;
 
     my $n = keys %options;
 
     my $oldfh = select STDOUT;
 
-    $self->calculate_summary(%options);
+    $options{files} = $files if $files && @$files;
+    $self->calculate_summary(%options, %$opts);
 
     my $format = sub
     {
@@ -691,7 +721,7 @@ sub uncoverable_comments
     open my $fh, "<", $file or do
     {
         warn "Devel::Cover: Can't open file $file: $!\n";
-        next;
+        return;
     };
     my @waiting;
     while (<$fh>)
@@ -776,7 +806,17 @@ sub objectify_cover
                 }
             }
         }
-        bless $_, "Devel::Cover::DB::Run" for values %{$self->{runs}};
+        for my $r (keys %{$self->{runs}})
+        {
+            if (defined $self->{runs}{$r})
+            {
+                bless $self->{runs}{$r}, "Devel::Cover::DB::Run";
+            }
+            else
+            {
+                delete $self->{runs}{$r};  # DEVEL_COVER_SELF
+            }
+        }
     }
 
     unless (exists &Devel::Cover::DB::Base::items)
@@ -859,6 +899,7 @@ sub cover
         last unless $st;
 
         my $r = $self->{runs}{$run};
+        next unless $r->{collected};  # DEVEL_COVER_SELF
         @{$self->{collected}}{@{$r->{collected}}} = ();
         $st->add_criteria(@{$r->{collected}});
         my $count = $r->{count};
@@ -868,7 +909,11 @@ sub cover
             my $digest = $r->{digests}{$file};
             unless ($digest)
             {
-                print STDERR "Devel::Cover: Can't find digest for $file\n";
+                print STDERR "Devel::Cover: Can't find digest for $file\n"
+                    unless $Devel::Cover::Silent ||
+                           $file =~ $Devel::Cover::DB::Ignore_filenames ||
+                           ($Devel::Cover::Self_cover &&
+                            $file =~ q|/Devel/Cover[./]|);
                 next;
             }
             # print STDERR "File: $file\n";
@@ -946,22 +991,22 @@ __END__
 
 Devel::Cover::DB - Code coverage metrics for Perl
 
+=head1 VERSION
+
+version 0.93
+
 =head1 SYNOPSIS
 
  use Devel::Cover::DB;
 
  my $db = Devel::Cover::DB->new(db => "my_coverage_db");
- $db->print_summary(statement => 1, pod => 1);
+ $db->print_summary([$file1, $file2], ["statement", "pod"]);
  $db->print_details;
 
 =head1 DESCRIPTION
 
 This module provides access to a database of code coverage information.
 
-=head1 SEE ALSO
-
- Devel::Cover
-
 =head1 METHODS
 
 =head2 new
@@ -994,13 +1039,26 @@ data may be accessed.
      }
  }
 
-Data for different criteria will be in different formats, so that will
-need special handling, but I'll deal with that when we have the data for
-different criteria.
+Data for different criteria will be in different formats, so that will need
+special handling.  This is not yet documented so your best bet for now is to
+look at some of the simpler reports and/or the source.
 
-If you don't want to remember all the method names, use values() instead
-of files(), criteria() and locations() and get() instead of file(),
-criterion() and location().
+The methods in the above example are actually aliases for methods in
+Devel::Cover::DB::Base (the base class for all Devel::Cover::DB::* classes):
+
+=over
+
+=item * Devel::Cover::DB::Base->values
+
+Aliased to Devel::Cover::DB::Cover->files, Devel::Cover::DB::File->criteria,
+Devel::Cover::DB::Criterion->locations, and Devel::Cover::DB::Location->data
+
+=item * Devel::Cover::DB::Base->get
+
+Aliased to Devel::Cover::DB::Cover->file, Devel::Cover::DB::File->criteriom,
+Devel::Cover::DB::Criterion->location, and Devel::Cover::DB::Location->datum
+
+=back
 
 Instead of calling $file->criterion("x") you can also call $file->x.
 
@@ -1008,20 +1066,24 @@ Instead of calling $file->criterion("x") you can also call $file->x.
 
  my $valid = $db->is_valid;
 
-Returns true iff the db is valid.  (Actually there is one too many fs there, but
-that's what it should do.)
+Returns true if $db is valid (or looks valid, the function is too lax).
+
+=head1 SEE ALSO
+
+ Devel::Cover
+ Devel::Cover::DB::Base
+ Devel::Cover::DB::Cover
+ Devel::Cover::DB::File
+ Devel::Cover::DB::Criterion
+ Devel::Cover::DB::Location
 
 =head1 BUGS
 
 Huh?
 
-=head1 VERSION
-
-Version 0.77 - 15th May 2011
-
 =head1 LICENCE
 
-Copyright 2001-2011, Paul Johnson (pjcj@cpan.org)
+Copyright 2001-2012, Paul Johnson (paul@pjcj.net)
 
 This software is free.  It is licensed under the same terms as Perl itself.
 
