@@ -8,7 +8,7 @@ use Devel::Cover::DB;
 use Devel::Cover::Html_Common "launch";
 use Devel::Cover::Truth_Table;
 
-our $VERSION = '0.89'; # VERSION
+our $VERSION = '0.93'; # VERSION
 our $LVERSION = do { eval '$VERSION' || "0.001" };  # for development purposes
 
 #-------------------------------------------------------------------------------
@@ -360,26 +360,32 @@ sub print_summary_report {
     my ($show, $th) = get_showing_headers($db, $options);
     push @$show, 'total';
 
+    my $le = sub { ($_[0] >   0 ? "&lt;" : "=") . " $_[0]%" };
+    my $ge = sub { ($_[0] < 100 ? "&gt;" : "") . "= $_[0]%" };
+    my @c = ( $le->($options->{report_c0}), $le->($options->{report_c1}),
+              $le->($options->{report_c2}), $ge->($options->{report_c2}) );
+    my $date = do
+    {
+        my ($sec, $min, $hour, $mday, $mon, $year) = localtime;
+        sprintf "%04d-%02d-%02d %02d:%02d:%02d",
+                $year + 1900, $mon + 1, $mday, $hour, $min, $sec
+    };
+    my $perl_v = $] < 5.010 ? $] : $^V;
+    my $os     = $^O;
+
     print_html_header($fh, $options->{option}{summarytitle});
     # TODO - >= 100% doesn't look nice.  See also Html_basic.
     print $fh <<"END_HTML";
 <body>
 <h1>$options->{option}{summarytitle}</h1>
 <table>
+  <tr><td class="h" align="right">Database:</td><td align="left" colspan="4">$db->{db}</td></tr>
+  <tr><td class="h" align="right">Report Date:</td><td align="left" colspan="4">$date</td></tr>
+  <tr><td class="h" align="right">Perl Version:</td><td align="left" colspan="4">$perl_v</td></tr>
+  <tr><td class="h" align="right">OS:</td><td align="left" colspan="4">$os</td></tr>
   <tr>
-    <td class="h" align="right">Database:</td><td align="left">$db->{db}</td>
-  </tr>
-  <tr>
-    <td class="h" align="right">C0:</td><td class="c0" align="left">&lt;&nbsp;$options->{report_c0}\%</td>
-  </tr>
-  <tr>
-    <td class="h" align="right">C1:</td><td class="c1" align="left">&lt;&nbsp;$options->{report_c1}\%</td>
-  </tr>
-  <tr>
-    <td class="h" align="right">C2:</td><td class="c2" align="left">&lt;&nbsp;$options->{report_c2}\%</td>
-  </tr>
-  <tr>
-    <td class="h" align="right">C3:</td><td class="c3" align="left">&gt;=&nbsp;$options->{report_c2}\%</td>
+    <td class="h" align="right">Thresholds:</td>
+    <td class="c0">$c[0]</td><td class="c1">$c[1]</td><td class="c2">$c[2]</td><td class="c3">$c[3]</td>
   </tr>
 </table>
 <div><br/></div>
@@ -474,10 +480,12 @@ sub print_file_report {
                   $db);
     print_th($out, ['line', @$th, 'code']);
 
+    my $autoloader = 0;
     while (my $sloc = <$in>) {
+        $autoloader ||= $sloc =~ /use\s+AutoLoader/;
 
         # Process stuff after __END__ or __DATA__ tokens
-        if ($sloc =~ /^__(END|DATA)__/) {
+        if (!$autoloader && $sloc =~ /^__(END|DATA)__/) {
             if ($opt->{option}{data}) {
                 # print all data in one cell
                 my ($i, $n) = ($., scalar @$th);
@@ -739,12 +747,11 @@ sub report {
 
 =head1 NAME
 
+Devel::Cover::Report::Html_minimal - HTML backend for Devel::Cover
 
 =head1 VERSION
 
-version 0.89
-Devel::Cover::Report::Html_minimal - Backend for HTML reporting of coverage
-statistics
+version 0.93
 
 =head1 SYNOPSIS
 
