@@ -1,4 +1,4 @@
-# Copyright 2002-2011, Paul Johnson (pjcj@cpan.org)
+# Copyright 2002-2012, Paul Johnson (paul@pjcj.net)
 
 # This software is free.  It is licensed under the same terms as Perl itself.
 
@@ -10,16 +10,14 @@ package Devel::Cover::Test;
 use strict;
 use warnings;
 
-our $VERSION = "0.77";
+our $VERSION = '0.93'; # VERSION
 
 use Carp;
 
 use File::Spec;
-use Test;
+use Test ();
 
-use Devel::Cover::Inc 0.77;
-
-my $Test;
+use Devel::Cover::Inc;
 
 sub new
 {
@@ -33,23 +31,36 @@ sub new
     my $criteria = delete $params{criteria} ||
                    "statement branch condition subroutine";
 
-    my $self =
+    eval "use Test::Differences";
+    my $differences = $INC{"Test/Differences.pm"};
+
+    my $self = bless
     {
         test             => $test,
-        criteria         => $criteria,
+        criteria         => [ $criteria ],
         skip             => "",
-        uncoverable_file => "",
+        uncoverable_file => [],
         select           => "",
-        ignore           => "",
-        run_test_at_end  => 1,
+        ignore           => [],
+        changes          => [],
+        test_parameters  => [],
+        debug            => $ENV{DEVEL_COVER_DEBUG} || 0,
+        differences      => $differences,
+        no_coverage      => $ENV{DEVEL_COVER_NO_COVERAGE} || 0,
         %params
-    };
-
-    $Test = bless $self, $class;
+    }, $class;
 
     $self->get_params
 }
 
+sub shell_quote
+{
+    my ($item) = @_;
+
+    $^O eq "MSWin32" ? (/ / and $_ = qq("$_")) : s/ /\\ /g for $item;
+    $item
+};
+
 sub get_params
 {
     my $self = shift;
@@ -59,50 +70,54 @@ sub get_params
     {
         while (<T>)
         {
-            $self->{$1} = $2 if /__COVER__\s+(\w+)\s+(.*)/;
+            push @{$self->{$1}}, $2 if /__COVER__\s+(\w+)\s+(.*)/;
         }
         close T or die "Cannot close $test: $!";
     }
 
-    $self->{select}         ||= "-select $self->{test}";
+    $self->{criteria} = $self->{criteria}[-1];
+
+    $self->{select}         ||= "-select /tests/$self->{test}\\b";
     $self->{test_parameters}  = "$self->{select}"
-                              . " -ignore blib Devel/Cover $self->{ignore}"
+                              . " -ignore blib Devel/Cover @{$self->{ignore}}"
                               . " -merge 0 -coverage $self->{criteria} "
-                              . ($self->{test_parameters} || "");
+                              . "@{$self->{test_parameters}}";
     $self->{criteria} =~ s/-\w+//g;
-    $self->{cover_db} = "$Devel::Cover::Inc::Base/t/e2e/cover_db_$self->{test}/";
-    mkdir $self->{cover_db};
+    $self->{cover_db} = "$Devel::Cover::Inc::Base/t/e2e/"
+                      . "cover_db_$self->{test}/";
+    unless (mkdir $self->{cover_db})
+    {
+        die "Can't mkdir $self->{cover_db}: $!" unless -d $self->{cover_db};
+    }
     $self->{cover_parameters} = join(" ", map "-coverage $_",
                                               split " ", $self->{criteria})
-                              . " -report text " . $self->{cover_db};
-    $self->{cover_parameters} .= " -uncoverable_file $self->{uncoverable_file}"
-        if $self->{uncoverable_file};
-    $self->{skip}             = $self->{skip_reason}
-        if exists $self->{skip_test} && eval "{$self->{skip_test}}";
+                              . " -report text "
+                              . shell_quote $self->{cover_db};
+    $self->{cover_parameters} .= " -uncoverable_file "
+                              .  "@{$self->{uncoverable_file}}"
+        if @{$self->{uncoverable_file}};
+    if (exists $self->{skip_test})
+    {
+        for my $s (@{$self->{skip_test}})
+        {
+            my $r = shift @{$self->{skip_reason}};
+            next unless eval "{$s}";
+            $self->{skip} = $r;
+            last;
+        }
+    }
 
     $self
 }
 
-sub test { $Test }
-
-sub shell_quote
-{
-    my ($item) = @_;
-    # properly quote the item
-    $^O eq "MSWin32" ? (/ / and $_ = qq("$_")) : s/ /\\ /g for $item;
-    $item
-};
-
 sub perl
 {
     my $self = shift;
 
-    my $perl = shell_quote $Devel::Cover::Inc::Perl;
-    my $base = $Devel::Cover::Inc::Base;
-
-    $perl .= " " . shell_quote "-I$base/$_" for "", "blib/lib", "blib/arch";
-
-    $perl
+    join " ",
+         map shell_quote($_),
+             $Devel::Cover::Inc::Perl,
+             map "-I$Devel::Cover::Inc::Base/$_", "", "blib/lib", "blib/arch"
 }
 
 sub test_command
@@ -110,10 +125,12 @@ sub test_command
     my $self = shift;
 
     my $c = $self->perl;
-    unless ($ENV{DEVEL_COVER_NO_COVERAGE})
+    unless ($self->{no_coverage})
     {
-        $c .= " -MDevel::Cover=" .
-              join(",", '-db', $self->{cover_db}, split ' ', $self->{test_parameters})
+        $c .= " "
+           .  shell_quote "-MDevel::Cover=" .
+                          join(",", "-db", $self->{cover_db},
+                                    split " ", $self->{test_parameters});
     }
     $c .= " " . shell_quote $self->test_file;
     $c .= " " . $self->test_file_parameters;
@@ -126,7 +143,7 @@ sub cover_command
     my $self = shift;
 
     my $b = shell_quote $Devel::Cover::Inc::Base;
-    my $c = $self->perl . " $b/cover $self->{cover_parameters}";
+    my $c = $self->perl . " $b/bin/cover $self->{cover_parameters}";
     $c
 }
 
@@ -169,7 +186,7 @@ sub cover_gold
     $v = $ENV{DEVEL_COVER_GOLDEN_VERSION}
         if exists $ENV{DEVEL_COVER_GOLDEN_VERSION};
 
-    "$td/$test.$v"
+    ("$td/$test", $v eq "5.0" ? 0 : $v)
 }
 
 sub run_command
@@ -177,14 +194,12 @@ sub run_command
     my $self = shift;
     my ($command) = @_;
 
-    my $debug = $ENV{DEVEL_COVER_DEBUG} || 0;
-
-    print STDERR "Running test [$command]\n" if $debug;
+    print STDERR "Running test [$command]\n" if $self->{debug};
 
     open T, "$command 2>&1 |" or die "Cannot run $command: $!";
     while (<T>)
     {
-        print STDERR if $debug;
+        print STDERR if $self->{debug};
     }
     close T or die "Cannot close $command: $!";
 
@@ -195,32 +210,37 @@ sub run_test
 {
     my $self = shift;
 
-    $self->{run_test_at_end} = 0;
+    if ($self->{skip})
+    {
+        Test::plan tests => 1;
+        Test::skip($self->{skip}, 1);
+        return;
+    }
 
-    my $debug = $ENV{DEVEL_COVER_DEBUG} || 0;
+    my $version = int(($] - 5) * 1000 + 0.5);
+    if ($version % 2 && $version < 16)
+    {
+        Test::plan tests => 1;
+        Test::skip("Perl version $] is an obsolete development version", 1);
+        return;
+    }
+
+    my ($base, $v) = $self->cover_gold;
+    return 1 unless $v;  # assume we are generating the golden results
+    my $gold = "$base.$v";
 
-    my $gold = $self->cover_gold;
     open I, $gold or die "Cannot open $gold: $!";
     my @cover = <I>;
     close I or die "Cannot close $gold: $!";
     $self->{cover} = \@cover;
 
-    # print STDERR "gold from $gold\n", @cover if $debug;
+    # print STDERR "gold from $gold\n", @cover if $self->{debug};
 
-    eval "use Test::Differences";
-    my $differences = $INC{"Test/Differences.pm"};
-
-    plan tests => ($differences || $self->{skip})
-                  ? 1
-                  : exists $self->{tests}
-                    ? $self->{tests}->(scalar @cover)
-                    : scalar @cover;
-
-    if ($self->{skip})
-    {
-        skip($self->{skip}, 1);
-        return;
-    }
+    Test::plan tests => $self->{differences}
+                            ? 1
+                            : exists $self->{tests}
+                                  ? $self->{tests}->(scalar @cover)
+                                  : scalar @cover;
 
     local $ENV{PERL5OPT};
 
@@ -231,18 +251,16 @@ sub run_test
     $self->run_cover unless $self->{no_report};
 
     $self->{end}->() if $self->{end};
+
+    1
 }
 
 sub run_cover
 {
     my $self = shift;
 
-    my $debug = $ENV{DEVEL_COVER_DEBUG} || 0;
-    eval "use Test::Differences";
-    my $differences = $INC{"Test/Differences.pm"};
-
     my $cover_com = $self->cover_command;
-    print STDERR "Running cover [$cover_com]\n" if $debug;
+    print STDERR "Running cover [$cover_com]\n" if $self->{debug};
 
     my @at;
     my @ac;
@@ -256,7 +274,7 @@ sub run_cover
         {
             $_ = scalar $get_line->();
             $_ = "" unless defined $_;
-            print STDERR $_ if $debug;
+            print STDERR $_ if $self->{debug};
             redo if /^Devel::Cover: merging run/;
             redo if /^Set up gcc environment/;  # for MinGW
             if (/Can't opendir\(.+\): No such file or directory/)
@@ -280,66 +298,77 @@ sub run_cover
             s/^(Finish: ).*/$1/;
             s/copyright .*//ix;
             no warnings "exiting";
-            eval $self->{changes} if exists $self->{changes};
+            eval join "; ", @{$self->{changes}};
             return $_;
         }
     };
 
+    # use Devel::Cover::Dumper; print STDERR "--->", Dumper $self->{changes};
     open T, "$cover_com 2>&1 |" or die "Cannot run $cover_com: $!";
     while (!eof T)
     {
         my $t = $change_line->(sub { <T> });
         my $c = $change_line->(sub { shift @{$self->{cover}} });
         # print STDERR "[$t]\n[$c]\n" if $t ne $c;
-        # chomp(my $tn = $t); chomp(my $cn = $c);
-        # print STDERR "c-[$tn] $.\ng=[$cn]\n";
-        if ($differences)
+        do
+        {
+            chomp(my $tn = $t); chomp(my $cn = $c);
+            print STDERR "c-[$tn] $.\ng=[$cn]\n";
+        } if $self->{debug};
+
+        if ($self->{differences})
         {
             push @at, $t;
             push @ac, $c;
         }
         else
         {
-            $ENV{DEVEL_COVER_NO_COVERAGE} ? ok 1 : ok $t, $c;
-            last if $ENV{DEVEL_COVER_NO_COVERAGE} && !@{$self->{cover}};
+            $self->{no_coverage} ? Test::ok 1 : Test::ok $t, $c;
+            last if $self->{no_coverage} && !@{$self->{cover}};
         }
     }
-    if ($differences)
+    if ($self->{differences})
     {
         no warnings "redefine";
         local *Test::_quote = sub { "@_" };
-        $ENV{DEVEL_COVER_NO_COVERAGE} ? ok 1 : eq_or_diff(\@at, \@ac, "output");
+        $self->{no_coverage} ? Test::ok 1 : eq_or_diff(\@at, \@ac, "output");
     }
-    elsif ($ENV{DEVEL_COVER_NO_COVERAGE})
+    elsif ($self->{no_coverage})
     {
-        ok 1 for @{$self->{cover}};
+        Test::ok 1 for @{$self->{cover}};
     }
     close T or die "Cannot close $cover_com: $!";
+
+    1
 }
 
 sub create_gold
 {
     my $self = shift;
 
-    $self->{run_test_at_end} = 0;
-
     # Pod::Coverage not available on all versions, but it must be there on
     # 5.6.1 and 5.8.0
     return if $self->{criteria} =~ /\bpod\b/ &&
                $] != 5.006001 &&
                $] != 5.008000;
 
-    my $debug = $ENV{DEVEL_COVER_DEBUG} || 0;
-
-    my $gold = $self->cover_gold;
-    my $new_gold = $gold;
-    $new_gold =~ s/(5\.\d+)$/$]/;
-    my $gv = $1;
-    my $ng = "";
+    my ($base, $v) = $self->cover_gold;
+    my $gold       = "$base.$v";
+    my $new_gold   = "$base.$]";
+    my $gv         = $v;
+    my $ng         = "";
 
     unless (-e $new_gold)
     {
         open my $g, ">$new_gold" or die "Can't open $new_gold: $!";
+        unlink $new_gold;
+    }
+
+    # use Devel::Cover::Dumper; print STDERR Dumper $self;
+    if ($self->{skip})
+    {
+        print STDERR "Skipping: $self->{skip}\n";
+        return;
     }
 
     $self->{run_test}
@@ -347,7 +376,7 @@ sub create_gold
         : $self->run_command($self->test_command);
 
     my $cover_com = $self->cover_command;
-    print STDERR "Running cover [$cover_com]\n" if $debug;
+    print STDERR "Running cover [$cover_com]\n" if $self->{debug};
 
     open G, ">$new_gold" or die "Cannot open $new_gold: $!";
     open T, "$cover_com 2>&1 |" or die "Cannot run $cover_com: $!";
@@ -357,38 +386,150 @@ sub create_gold
         $l =~ s/^($_: ).*$/$1.../
             for "Run", "Perl version", "OS", "Start", "Finish";
         $l =~ s/^(Reading database from ).*$/$1.../;
-        print STDERR $l if $debug;
+        print STDERR $l if $self->{debug};
         print G $l;
         $ng .= $l;
     }
     close T or die "Cannot close $cover_com: $!";
     close G or die "Cannot close $new_gold: $!";
 
-    print STDERR "gv is $gv and this is $]\n" if $debug;
-    print STDERR "gold is $gold and new_gold is $new_gold\n" if $debug;
-    unless ($gv eq "5.0" || $gv eq $])
+    print STDERR "gv is $gv and this is $]\n" if $self->{debug};
+    print STDERR "gold is $gold and new_gold is $new_gold\n" if $self->{debug};
+    unless ($gv eq "0" || $gv eq $])
     {
         open G, "$gold" or die "Cannot open $gold: $!";
         my $g = do { local $/; <G> };
         close G or die "Cannot close $gold: $!";
 
-        print STDERR "checking $new_gold against $gold\n" if $debug;
+        print STDERR "checking $new_gold against $gold\n" if $self->{debug};
         # print "--[$ng]--\n";
         # print "--[$g]--\n";
         if ($ng eq $g)
         {
-            print "Output from $new_gold matches $gold\n";
+            print "matches $v";
             unlink $new_gold;
         }
     }
 
     $self->{end}->() if $self->{end};
+
+    1
 }
 
-END
-{
-    my $self = $Test;
-    $self->run_test if $self->{run_test_at_end};
-}
+1
 
-1;
+__END__
+
+=head1 NAME
+
+Devel::Cover::Test - Internal module for testing
+
+=head1 VERSION
+
+version 0.93
+
+=head1 METHODS
+
+=cut
+
+=head2 new
+
+  my $test = Devel::Cover::Test->new($test, criteria => $string)
+
+Constructor.
+
+"criteria" parameter (optional, defaults to "statement branch condition
+subroutine") is a space separated list of tokens.
+Supported tokens are "statement", "branch", "condition", "subroutine" and
+"pod".
+
+More optional parameters are supported. Refer to L</get_params> sub.
+
+=head2 shell_quote
+
+  my $quoted_item = shell_quote($item)
+
+Returns properly quoted item to cope with embedded spaces.
+
+=head2 perl
+
+  my $perl = $self->perl()
+
+Returns absolute path to Perl interpreter with proper -I options (blib-wise).
+
+=head2 test_command
+
+  my $command = $self->test_command()
+
+Returns test command, made of:
+
+=over 4
+
+=item absolute path to Perl interpreter
+
+=item Devel::Cover -M option (if applicable)
+
+=item test file
+
+=item test file parameters (if applicable)
+
+=back
+
+=head2 cover_command
+
+  my $command = $self->cover_command()
+
+Returns test command, made of:
+
+=over 4
+
+=item absolute path to Perl interpreter
+
+=item absolute path to cover script
+
+=item cover parameters
+
+=back
+
+=head2 test_file
+
+  my $file = $self->test_file()
+
+Returns absolute path to test file.
+
+=head2 test_file_parameters
+
+  my $parameters = $self->test_file_parameters()
+
+Accessor to test_file_parameters property.
+
+=head2 cover_gold
+
+  my ($base, $v) = $self->cover_gold;
+
+Returns the absolute path of the base to the golden file and the suffix
+version number.
+
+$base comes from the name of the test and $v will be $] from the earliest perl
+version for which the golden results should be the same as for the current $]
+
+=head2 run_command
+
+  $self->run_command($command)
+
+Runs command, most likely obtained from L</test_command> sub.
+
+=head1 BUGS
+
+Huh?
+
+=head1 LICENCE
+
+Copyright 2001-2012, Paul Johnson (paul@pjcj.net)
+
+This software is free.  It is licensed under the same terms as Perl itself.
+
+The latest version of this software should be available from my homepage:
+http://www.pjcj.net
+
+=cut
